==> FormBrowser-0.4.tar.gz: FormBrowser/lang/en_US.php <==
<?php
$lang['fbrp_searchsubmit']='Search';
$lang['fbrp_searchcancel']='Cancel last search';

$lang['browser_deleted'] = 'The browser has been deleted';
$lang['friendlyname'] = 'Form Browser';
$lang['postinstall'] = 'Form Browser has been installed!';
$lang['postuninstall'] = 'Form Browser has been uninstalled.';
$lang['really_uninstall'] = 'You\'re sure you want to uninstall Form Browser?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Form browser allows you to build simple database applications based upon the forms from Form Builder.';
$lang['you_need_permission'] = 'To access this, you need permission "%s"';

$lang['lackpermission'] = 'You lack permission to perform this operation';
$lang['error'] = 'Error!';
$land['admin_title'] = 'Form Browser Admin Panel';
$lang['admindescription'] = 'Administer approve/edit/configure Forms';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'FormBrowser has been installed!';
$lang['title_browsers'] = 'Form Browsers';
$lang['title_add_new_browser']='Add New Form Browser';
$lang['title_configuration'] = 'Configuration';
$lang['tab_main']='Form Browser';
$lang['tab_user_options']='User-side Options';
$lang['tab_admin_options']='Admin Options';
$lang['title_browser_user_list_template']='User List Template';
$lang['title_browser_user_full_template']='User Record View Template';
$lang['title_browser_admin_list_template']='Admin List Template';
$lang['title_browser_admin_full_template']='Admin Record View Template';
$lang['default_user_list_template']='Default User List Template';
$lang['default_user_full_template']='Default User Record View Template';
$lang['default_admin_list_template']='Default Admin List Template';
$lang['default_admin_full_template']='Default Admin Record View Template';
$lang['browser_template_name'] = 'from %s';
$lang['title_browser_name']='Browser Name';
$lang['title_browser_alias']='Browser Alias';
$lang['title_browser_administer']='Administer';
$lang['title_browser_export']='Export';
$lang['title_browser_type']='Browser Type';
$lang['title_date_format']='Date Format';
$lang['simple_browser'] = 'Simple Browser';
$lang['advanced_browser'] = 'Advanced Browser';
$lang['type_help'] = 'Simple Browsers will allow you to select which fields are visible and in which order (and allow template customization), while Advanced Browsers require you to do the full template customization.';
$lang['title_date_format_help']='Date Formats are built using standard PHP "date" format codes. For a reference, please view <a href="http://us4.php.net/manual/en/function.date.php">http://us4.php.net/manual/en/function.date.php</a>. Remember to escape any characters you don\'t want interpreted as date format codes!';
$lang['title_browser_css_class']='CSS Class for Browser';
$lang['title_form_id']='Form to Browse';
$lang['are_you_sure_delete_browser']='Are you sure you want to delete %s';
$lang['select_form']='Select a Form';
$lang['do_not_display']='Do Not Display';
$lang['title_field_name']='Field Name';
$lang['title_field_count']='Form contains %s visible fields';
$lang['title_list_order']='Display Order in List';
$lang['title_full_order']='Display Order in Full View';
$lang['title_admin_list_order']='Display Order in Admin List';
$lang['title_admin_full_order']='Display Order in Admin Full View';
$lang['title_rows_per_page']='Rows per page (in list view)';
$lang['title_admin_rows_per_page']='Rows per page (in list view)';
$lang['title_require_admin_approval']='Require Admin Approval?';
$lang['title_require_admin_approval_long']='Require admin approval of records before they\'re visible to users? (Admin approval is through the FormBrower admin interface)';
$lang['title_require_user_approval']='Require User Verification?';
$lang['title_require_user_approval_long']='Require user verification of records before they\'re visible to admin or other users? <br />(User verification requires that the form have a "Email Address Verification" field)';
$lang['title_allow_user_add']='Allow users to add records?';
$lang['title_allow_user_edit']='Allow users to edit records?';
$lang['title_allow_user_delete']='Allow users to delete records?';
$lang['title_allow_user_add_long']='Provide a link to the form to allow users to add new records?';
$lang['title_allow_user_edit_long']='Allow users to edit records?';
$lang['title_allow_user_delete_long']='Allow users to delete records?';
$lang['title_load_template'] = 'Load template';
$lang['title_submit_date']='Date Submitted';
$lang['title_approval_date']='Admin Approved';
$lang['title_user_approved']='User Approved';
$lang['title_add_new_resp']='Add a Record';
$lang['title_related_form']='Related Form';
$lang['title_browser_search_field']='Field to display as the record\'s title when a record is shown in site search results';
$lang['are_you_sure_delete_resp']='Are you sure you want to delete this response?';
$lang['must_save']='You must save your browser once for the fields to be available to the templates.';
$lang['title_strip_on_export'] = 'Strip HTML tags on export?';
$lang['title_strip_on_export_long'] = 'Remove all HTML tags in records when exported to Excel?';
$lang['title_export_file']='Non-memory Excel exports?';
$lang['title_udt_name']='User Defined Tag to call before rendering FormBrowser data';
$lang['title_export_file_long']='Using this option creates a file in your <i>uploads</i> directory rather than processing the export in memory. This is good if you have a large number of records. The downside is that you then need to manually delete the file after you have downloaded it.';
$lang['title_export_file_encoding']='Encoding/Code Page to use for downloaded Excel file (applies to in-memory exports only)';
$lang['title_suppress_email_on_edit']='Suppress Email Dispositions on record edit?';
$lang['help_suppress_email_on_edit']='If a form has a disposition that sends email, it will send those emails if the record is edited via the FormBrowser Admin. Check this box to prevent that.';
$lang['delete_selected_records']='Are you sure you want to delete the selected records?';
$lang['template_are_you_sure']='Are you sure you want to overwrite your template with the selected template? (Even if you say OK, you will still need to save the change)';
$lang['select_deselect_all']='Set/Unset All';
$lang['add']='Add Browser';
$lang['added']='Added';
$lang['save']='Save';
$lang['saved']='Saved';
$lang['update']='Update Browser';
$lang['updated'] = 'Updated.';
$lang['deleted']='Deleted.';
$lang['edit']='Edit';
$lang['delete']='Delete';
$lang['view']='View';
$lang['none']='None';
$lang['prefs_updated'] = 'Preferences Updated.';
$lang['browser']='Browser %s';
$lang['save_and_continue']='Save and Continue Editing';
$lang['unapproved'] = 'Approve this';
$lang['approved']='Approved. Click to un-approve';
$lang['next']='next&gt;';
$lang['previous']='&lt;previous';
$lang['pageof']='Page %s of %s';
$lang['response_list'] = 'Responses';
$lang['back']='&lt; Back';

$lang['exporttoexcel']='Export (tab delimited)';
$lang['export_spec']='FormBuilderExport-%s-%s.xls';


$lang['formbrowser_params_general']='General Params';
$lang['formbrowser_params_form_id']='Form Id';
$lang['formbrowser_params_browser_id']='Browser Id';
$lang['formbrowser_params_form_name']='form name, used by Form Builder';
$lang['formbrowser_params_browser_name']='browser name';
$lang['formbrowser_params_field_id']='internal field ID';
$lang['formbrowser_params_response_id']='internal response ID';
$lang['formbrowser_params_record_id']='unused';
$lang['formbrowser_params_page']='page number if paginating';
$lang['formbrowser_params_sort_field']='Name of field for sorting browser';
$lang['formbrowser_params_sort_dir']='Sort direction ("a" - ascending, "d" - descending)';
$lang['formbrowser_params_filter_field']='Field designator to filter results by. If this is set, only records where filter_field = filter_value will show up in the results. For high-performance, use "index1"-"index5" which correspond to your sort fields.';
$lang['formbrowser_params_filter_value']='Value to match for doing field filtering.';


$lang['event_info_OnFormBrowserRecordEdit']='Event triggered when a record is Edited';
$lang['event_info_OnFormBrowserRecordAdd']='Event triggered when a record is Added';
$lang['event_info_OnFormBrowserRecordDelete']='Event triggered when a record is Deleted';
$lang['event_info_OnFormBrowserRecordView']='Event triggered when a record is viewed';
$lang['event_info_OnFormBrowserRecordEditPostSave']='Event triggered after an edited record is saved';
$lang['event_info_OnFormBrowserRecordAddPostSave']='Event triggered after a new record is saved';

$lang['event_help_OnFormBrowserRecordEdit']='<p>Event triggered when a record is Edited</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordAdd']='<p>Event triggered when a record is Added</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordDelete']='<p>Event triggered when a record is Deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordView']='<p>Event triggered when a record is viewed</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';


$lang['changelog'] = '<ul>
	<li>Version 0.4 - Jan 2011. Fixed Bugs #1822, #791, #3463, #3880, #5154, plus an additional fix for Bug #1204 and several other bugs. Added ability to filter by index fields.</li>
	<li>Version 0.3.2 - Aug 2010. Bug fixes.</li>
	<li>Version 0.3.1 - Jul 2010. Numerous Bug fixes. Bulk deletion of records. Character encoding options for Excel download. Option for UDT calls before rendering templates to allow for crazy customization. Integration into CMS search.</li>
	<li>Version 0.3 - Dec 2009. Bug fixes.</li>
	<li>Version 0.3b2 - Nov 2009. Bug fixes.</li>
	<li>Version 0.3b1 - Nov 2009. Rewrite, optimization, improvements.</li>
	<li>Version 0.2.3 - 30 May 2008. Alberto Benati\'s search code.</li>
	<li>Version 0.2.2 - 30 April 2008. Minor bug fix for parameters from tag.</li>
	<li>Version 0.2.1 - 28 April 2008. Bug fixes, column sorting, rewrite of Excel export.</li>
	<li>Version 0.2 - 15 Aug 2007. Upgraded to work with CMS Made Simple 1.1</li>
<li>Version 0.1 - 8 July 2006. Initial Release.</li></ul>';
$lang['help'] = "<h3>What Does This Do?</h3>
<p>Form browser allows you to build simple database applications based upon the forms from Form Builder.</p>
<h3>How Do I Use It?</h3>
<P>Install it, and poke around the menus. Play with it. Try creating browsers, and adding them to your content.
If you get stuck, chat with me on the #cms IRC channel, post to the forum, send me email, or, if you're
really desperate, read the rest of this page.</P>

<h3>How Do I Create a Browser?</h3>
<p>In the CMS Admin Menu, you should get a new menu item called FormBrowser under Content. Click on this. On the page
that gets shown, there are options (at the bottom of the list of Browsers, if any) to Add a New Browser or Modify
Configuration.</p>
<p>Once you've created a browser, you need to select a FormBuilder form for which it displays results. If this FormBuilder form doesn't use the Database Disposition, you're not going to see any results, so make sure you pick a form that makes sense!</p>
<p>Once you've selected a form, you can re-order the field display in four places: the list view and the detail or full view, both on the user side and the admin side. You can also set a bunch of options, such as the number of rows displayed in list views, whether or not editing/adding/deleting is permitted on the user side, and so on. You can edit the templates for the display of the list view and full detail view on the user side.</p>
<p>When re-ordering fields, make sure that you think of the numbers as \"slots\" rather than \"weights\" -- in other words, don't use the same order number for two different fields, or it won't work the way you think it should.</p>
<h3>Administering a Browser</h3>
<p>By clicking on the key next to a browser in the admin list, you can go in and add/edit/delete/approve/disapprove records. If the form was created with User Approval, you won't see it in the admin unless the user has validated.</p>

<h3>Adding a Browser to a Page</h3>
<p>In the main FormBrowser admin page, you can see an example of the tag used to display each form. It looks
something like {cms_module module='FormBrowser' browser='sample_browser'}</p>
<p>By copying this tag into the content of a page, or into a template, will cause that browser to be displayed.
In theory, you can have multiple browsers on a page if you really want to, although this would be a sure sign of mental impairment and total disregard for database abuse. Be careful when pasting the tag
into a page's content if you use a WYSIWYG editor such as TinyMCE or HTMLArea. These editors may stealthily
change the quote marks (\") into HTML entities (&amp;quot;), and the browser will not show up. Try using
single quotes (') or editing the HTML directly.</p>
<h3>Sorting</h3>
<p>This is now implemented internally by the Index Fields setting in FormBuilder. When you
add a FormBrowser disposition to a form, you select which fields are sortable. They magically
become sortable here in FormBrowser.</p>
<p>If you do NOT want columns to be sortable, edit your template. Look for the section that is like:<br />
<pre>{section name=namelist start=0 loop=\$count}
		<th>{\$sortingnames[\$smarty.section.namelist.index]}</th>
{/section}
</pre>
<p>Use \$sortingnames if you want the columns to be sortable, use \$names if you don't.</p>
<h3>Filtering Search Results</h3>
<p>if you add filter_field=\"name\" and filter_value=\"value\" to your FormBrowser tag, only records where the \"name\" field has the value \"value\" will be listed. Valid field names for filtering are \"index1\" through
\"index5\" which correspond the the sortable fields.</p>

<h3>Troubleshooting</h3>
<ol><li> First step is to check you're running CMS 1.6 or later.</li>
<li> Second step is to read and understand the caveat about WYSIWYG editors up in the
section <em>Adding a Browser to a Page</em>.</li>
<li> Read the note above about making sure your form has a FormBrowser Disposition!</li>
<li> Use unique ordering of fields in the Browser configuration. Using position 1 for two different fields, for example, will clobber one of the two.</li>
<li> Last resport is to email me or catch me on IRC and we can go from there.</li>
</ol> 
<p>This is a newer version, but I did not get a lot of response to the beta test, so it is probably still buggy. While I've done all I can
to make sure no egregious bugs have crept in, rumor has it that more locusts lurk in it than a biblical plague. Prayer may or may not help.</p>
<p>The final release will include bug fixes, documentation, and will never run out of beer.</p>

<h3>Known Issues</h3>
<ul>
<li>FormBrowser does not yet support pretty urls</li>
<li>FormBrowser documentation is horrible. Someone should sponsor me to do a better job.</li>
</ul>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the CMS Made Simple  <a href=\"http://dev.cmsmadesimple.org\">Developer Forge</a>.</li>
<li>To obtain commercial support, please send an email to the author at <a href=\"mailto:sjg@cmsmodules.com\">&lt;sjg@cmsmodules.com&gt;</a>.</li>
<li>Additional discussion of this module may also be found in the <a href=\"http://forum.cmsmadesimple.org\">CMS Made Simple Forums</a>.</li>
<li>The author can often be found in the <a href=\"irc://irc.freenode.net/#cms\">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly and grovelling for free support.</li>  
</ul>
<p>Keep in mind that the author has put <em>hundreds and hundreds of hours</em> into the development of this module.
Please take the time to read the documentation before sending questions. Either that, or send your questions written on
financially negotiable instruments (i.e., checks or cash). Hint, hint. OK, screw subtlety: ".
'<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
<input type="hidden" name="encrypted" value="-----BEGIN PKCS7-----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-----END PKCS7-----
">
</form>'."
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2009, Samuel Goldstein <a href=\"mailto:sjg@cmsmodules.com\">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">GNU Public License</a>. You must agree to this license before using the module.</p>";

?>

==> FormBrowser-0.5.tar.gz: FormBrowser/lang/en_US.php <==
<?php
$lang['fbrp_searchsubmit']='Search';
$lang['fbrp_searchcancel']='Cancel last search';

$lang['browser_deleted'] = 'The browser has been deleted';
$lang['friendlyname'] = 'Form Browser';
$lang['postinstall'] = 'Form Browser has been installed!';
$lang['postuninstall'] = 'Form Browser has been uninstalled.';
$lang['really_uninstall'] = 'You\'re sure you want to uninstall Form Browser?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Form browser allows you to build simple database applications based upon the forms from Form Builder.';
$lang['you_need_permission'] = 'To access this, you need permission "%s"';

$lang['lackpermission'] = 'You lack permission to perform this operation';
$lang['error'] = 'Error!';
$land['admin_title'] = 'Form Browser Admin Panel';
$lang['admindescription'] = 'Administer approve/edit/configure Forms';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'FormBrowser has been installed!';
$lang['title_browsers'] = 'Form Browsers';
$lang['title_add_new_browser']='Add New Form Browser';
$lang['title_configuration'] = 'Configuration';
$lang['tab_main']='Form Browser';
$lang['tab_user_options']='User-side Options';
$lang['tab_admin_options']='Admin Options';
$lang['title_browser_user_list_template']='User List Template';
$lang['title_browser_user_full_template']='User Record View Template';
$lang['title_browser_admin_list_template']='Admin List Template';
$lang['title_browser_admin_full_template']='Admin Record View Template';
$lang['default_user_list_template']='Default User List Template';
$lang['default_user_full_template']='Default User Record View Template';
$lang['default_admin_list_template']='Default Admin List Template';
$lang['default_admin_full_template']='Default Admin Record View Template';
$lang['browser_template_name'] = 'from %s';
$lang['title_browser_name']='Browser Name';
$lang['title_browser_alias']='Browser Alias';
$lang['title_browser_administer']='Administer';
$lang['title_browser_export']='Export';
$lang['title_browser_type']='Browser Type';
$lang['title_date_format']='Date Format';
$lang['simple_browser'] = 'Simple Browser';
$lang['advanced_browser'] = 'Advanced Browser';
$lang['type_help'] = 'Simple Browsers will allow you to select which fields are visible and in which order (and allow template customization), while Advanced Browsers require you to do the full template customization.';
$lang['title_date_format_help']='Date Formats are built using standard PHP "date" format codes. For a reference, please view <a href="http://php.net/manual/en/function.date.php">http://php.net/manual/en/function.date.php</a>. Remember to escape any characters you don\'t want interpreted as date format codes!';
$lang['title_browser_css_class']='CSS Class for Browser';
$lang['title_form_id']='Form to Browse';
$lang['are_you_sure_delete_browser']='Are you sure you want to delete %s';
$lang['select_form']='Select a Form';
$lang['do_not_display']='Do Not Display';
$lang['title_field_name']='Field Name';
$lang['title_field_count']='Form contains %s visible fields';
$lang['title_list_order']='Display Order in List';
$lang['title_full_order']='Display Order in Full View';
$lang['title_admin_list_order']='Display Order in Admin List';
$lang['title_admin_full_order']='Display Order in Admin Full View';
$lang['title_rows_per_page']='Rows per page (in list view)';
$lang['title_admin_rows_per_page']='Rows per page (in list view)';
$lang['title_require_admin_approval']='Require Admin Approval?';
$lang['title_require_admin_approval_long']='Require admin approval of records before they\'re visible to users? (Admin approval is through the FormBrower admin interface)';
$lang['title_require_user_approval']='Require User Verification?';
$lang['title_require_user_approval_long']='Require user verification of records before they\'re visible to admin or other users? <br />(User verification requires that the form have a "Email Address Verification" field)';
$lang['title_allow_user_add']='Allow users to add records?';
$lang['title_allow_user_edit']='Allow users to edit records?';
$lang['title_allow_user_delete']='Allow users to delete records?';
$lang['title_allow_user_add_long']='Provide a link to the form to allow users to add new records?';
$lang['title_allow_user_edit_long']='Allow users to edit records?';
$lang['title_allow_user_delete_long']='Allow users to delete records?';
$lang['title_load_template'] = 'Load template';
$lang['title_submit_date']='Date Submitted';
$lang['title_approval_date']='Admin Approved';
$lang['title_user_approved']='User Approved';
$lang['title_add_new_resp']='Add a Record';
$lang['title_related_form']='Related Form';
$lang['title_response_id']='Response ID';
$lang['title_browser_search_field']='Field to display as the record\'s title when a record is shown in site search results';
$lang['are_you_sure_delete_resp']='Are you sure you want to delete this response?';
$lang['must_save']='You must save your browser once for the fields to be available to the templates.';
$lang['title_strip_on_export'] = 'Strip HTML tags on export?';
$lang['title_strip_on_export_long'] = 'Remove all HTML tags in records when exported to Excel?';
$lang['title_export_file']='Non-memory Excel exports?';
$lang['title_udt_name']='User Defined Tag to call before rendering FormBrowser data';
$lang['title_export_file_long']='Using this option creates a file in your <i>uploads</i> directory rather than processing the export in memory. This is good if you have a large number of records. The downside is that you then need to manually delete the file after you have downloaded it.';
$lang['title_export_file_encoding']='Encoding/Code Page to use for downloaded Excel file (applies to in-memory exports only)';
$lang['title_suppress_email_on_edit']='Suppress Email Dispositions on record edit?';
$lang['help_suppress_email_on_edit']='If a form has a disposition that sends email, it will send those emails if the record is edited via the FormBrowser Admin. Check this box to prevent that.';
$lang['title_show_response_id_in_export']='Show Response ID in exports';
$lang['title_show_response_id_in_export_long']='Show the Form Browser Response ID (database record ID) in Form Browser exported files.';
$lang['delete_selected_records']='Are you sure you want to delete the selected records?';
$lang['template_are_you_sure']='Are you sure you want to overwrite your template with the selected template? (Even if you say OK, you will still need to save the change)';
$lang['select_deselect_all']='Set/Unset All';
$lang['add']='Add Browser';
$lang['administrite']='Administer';
$lang['added']='Added';
$lang['save']='Save';
$lang['saved']='Saved';
$lang['update']='Update Browser';
$lang['updated'] = 'Updated.';
$lang['deleted']='Deleted.'; // Necessary?
$lang['edit']='Edit';
$lang['delete']='Delete';
$lang['view']='View';
$lang['none']='None';
$lang['prefs_updated'] = 'Preferences Updated.';
$lang['browser']='Browser %s';
$lang['save_and_continue']='Save and Continue Editing';
$lang['unapproved'] = 'Approve this';
$lang['approved']='Approved. Click to un-approve';
$lang['next']='next&gt;';
$lang['previous']='&lt;previous';
$lang['pageof']='Page %s of %s';
$lang['response_list'] = 'Responses';
$lang['back']='&lt; Back';

$lang['exporttoexcel']='Export (tab delimited)';
$lang['export_spec']='FormBuilderExport-%s-%s.csv';
$lang['separator']='Separator';
$lang['enclosure']='Enclosure';

$lang['message_nothing_deleted']='Nothing deleted';
$lang['message_responses_deleted']='%s response\'s deleted';

$lang['formbrowser_params_general']='General Params';
$lang['formbrowser_params_form_id']='Form Id';
$lang['formbrowser_params_browser_id']='Browser Id';
$lang['formbrowser_params_form_name']='form name, used by FormBuilder';
$lang['formbrowser_params_browser_name']='browser name';
$lang['formbrowser_params_field_id']='internal field ID';
$lang['formbrowser_params_response_id']='internal response ID';
$lang['formbrowser_params_record_id']='unused';
$lang['formbrowser_params_page']='page number if paginating';
$lang['formbrowser_params_sort_field']='Name of field for sorting browser';
$lang['formbrowser_params_sort_dir']='Sort direction ("a" - ascending, "d" - descending)';
$lang['formbrowser_params_filter_field']='Field designator to filter results by. If this is set, only records where filter_field = filter_value will show up in the results. For high-performance, use "index1"-"index5" which correspond to your sort fields.';
$lang['formbrowser_params_filter_value']='Value to match for doing field filtering.';


$lang['event_info_OnFormBrowserRecordEdit']='Event triggered when a record is Edited';
$lang['event_info_OnFormBrowserRecordAdd']='Event triggered when a record is Added';
$lang['event_info_OnFormBrowserRecordDelete']='Event triggered when a record is Deleted';
$lang['event_info_OnFormBrowserRecordView']='Event triggered when a record is viewed';
$lang['event_info_OnFormBrowserRecordEditPostSave']='Event triggered after an edited record is saved';
$lang['event_info_OnFormBrowserRecordAddPostSave']='Event triggered after a new record is saved';

$lang['event_help_OnFormBrowserRecordEdit']='<p>Event triggered when a record is Edited</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordAdd']='<p>Event triggered when a record is Added</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordDelete']='<p>Event triggered when a record is Deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';
$lang['event_help_OnFormBrowserRecordView']='<p>Event triggered when a record is viewed</p>
<h4>Parameters</h4>
<ul>
<li><em>browser_name</em> - The browser name (string)</li>
<li><em>record_id</em> - The internal response id (int)</li>
<li><em>side</em> - where the operation was performed ("admin" or "user")</li>
</ul> ';

?>
